@@ -162,6 +162,7 @@ use futures::stream::Stream;
 use ql2::term::TermType;
 use serde::de::DeserializeOwned;
 use serde::Serialize;
+use std::borrow::Cow;
 use std::str;
 
 #[derive(Debug, Clone, Copy, Serialize, Eq, PartialEq, Ord, PartialOrd, Hash)]
@@ -179,6 +180,31 @@ pub enum ReadMode {
     Outdated,
 }
 
+pub trait StaticString {
+    fn static_string(self) -> Cow<'static, str>;
+}
+
+impl StaticString for &'static str {
+    fn static_string(self) -> Cow<'static, str> {
+        Cow::from(self)
+    }
+}
+
+impl StaticString for String {
+    fn static_string(self) -> Cow<'static, str> {
+        Cow::from(self)
+    }
+}
+
+impl StaticString for &Cow<'static, str> {
+    fn static_string(self) -> Cow<'static, str> {
+        match self {
+            Cow::Borrowed(string) => Cow::Borrowed(*string),
+            Cow::Owned(string) => Cow::Owned(string.to_owned()),
+        }
+    }
+}
+
 fn debug(bytes: &[u8]) -> String {
     if let Ok(string) = str::from_utf8(bytes) {
         return string.to_owned();
